Workshops and show cases
========================

**wavy** has been used in mutliple workshops to provide training on using wave observations from satellite altimeters and subsequent wave model validation. The examples that were used in the most recent workshops are presented here.

.. note::

    Across the years, the workshops have been performed using various versions of wavy which reflects in the code and output examples. This is kept in its original form to allow the participants to return to the examples they used. Most of the here demonstrated use cases are also under the tutorials which are always updated to the latest **wavy** code.

.. toctree::
   :maxdepth: 3

   workshop_latest
   vietnam21
   vietnam22
   vietnam22_2
   vietnam25
   mozambique23
   mozambique24
